@@ -3,16 +3,15 @@
 import inspect
 from enum import Enum
 from functools import wraps
-from typing import Callable, List, Optional, Type, Any, Dict
+from typing import Any, Callable, Dict, List, Optional, Type
+
+from fastapi.responses import JSONResponse, Response
 from pydantic import BaseModel, create_model
-from fastapi.responses import Response, JSONResponse
-
-from ..schemas.response import SuccessResponse, FailedResponse, ResponseBase
 
+from ..schemas.response import FailedResponse, ResponseBase, SuccessResponse
 from .authentication import Auth, auth_data_class_to_dependency
 from .response import return_response
 
-
 __all__ = (
     "RouteMethod",
     "Route",
@@ -107,9 +106,7 @@ class Route:
             model_name = getattr(response_model, "__name__", "SuccessfulResponse")
             data_type = response_model or Any
             default_value = (
-                default_response_model
-                if default_response_model is not None
-                else ...
+                default_response_model if default_response_model is not None else ...
             )
             self.response_model = create_model(
                 model_name,
