@@ -1,8 +1,9 @@
 import hashlib
 import json
 import zlib
-from typing import Any, Callable, Dict, Set, List
 from functools import wraps
+from typing import Any, Callable, Dict, List, Set
+
 from redis import Redis
 
 from ..core.exception import exception_to_dict
@@ -10,7 +11,6 @@ from ..core.jsonable_encoder import jsonable_encoder
 from ..log import footprint
 from .connection import RedisInstance
 
-
 __all__ = (
     "cache_function",
     "cache_wrapper",
@@ -74,9 +74,9 @@ def cache_function(
     *args,
     **kwargs,
 ):
-    """
-    Call a function with caching support. If a cached value exists in Redis, it is returned.
-    Otherwise, the function is executed, its result is cached, and then returned.
+    """Call a function with caching support. If a cached value exists in Redis,
+    it is returned. Otherwise, the function is executed, its result is cached,
+    and then returned.
 
     :param redis: An instance of redis class.
     :param skip_cache_keys: The keys that we should not involve them in caching:
